==> applet-service-2.0.0-20190923.032242-2-sources.jar: com/bizvane/appletservice/models/bo/UpdateMemberInfo.java <==
package com.bizvane.appletservice.models.bo;

/**
 * @ClassName UpdateMemberInfo
 * @DescriptTion :
 * @Auther: wd
 * @Date :2018/12/28 14:23
 */
public class UpdateMemberInfo {

    /**
     * code : 179011264953
     * card_id : p1Pj9jr90_SQRaVqYI239Ka1erkI
     * background_pic_url : https://mmbiz.qlogo.cn/mmbiz/0?wx_fmt=jpeg
     * record_bonus : 消费30元，获得3积分
     * bonus : 3000
     * add_bonus : 30
     * balance : 3000
     * add_balance : -30
     * record_balance : 购买焦糖玛琪朵一杯，扣除金额30元。
     * custom_field_value : xxxxx
     * custom_field_value2 : xxxxx
     * notify_optional : {"is_notify_bonus":true,"is_notify_balance":true,"is_notify_custom_field1":true}
     */
    private Long sysBrandId;
    private String code;
    private String card_id;
    private String custom_field_value1;
    private String custom_field_value2;
    private String custom_field_value3;

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getCard_id() {
        return card_id;
    }

    public void setCard_id(String card_id) {
        this.card_id = card_id;
    }

    public String getCustom_field_value1() {
        return custom_field_value1;
    }

    public void setCustom_field_value1(String custom_field_value1) {
        this.custom_field_value1 = custom_field_value1;
    }

    public String getCustom_field_value2() {
        return custom_field_value2;
    }

    public void setCustom_field_value2(String custom_field_value2) {
        this.custom_field_value2 = custom_field_value2;
    }

    public String getCustom_field_value3() {
        return custom_field_value3;
    }

    public void setCustom_field_value3(String custom_field_value3) {
        this.custom_field_value3 = custom_field_value3;
    }

    @Override
    public String toString() {
        return "UpdateMemberInfo{" +
                "sysBrandId=" + sysBrandId +
                ", code='" + code + '\'' +
                ", card_id='" + card_id + '\'' +
                ", custom_field_value1='" + custom_field_value1 + '\'' +
                ", custom_field_value2='" + custom_field_value2 + '\'' +
                ", custom_field_value3='" + custom_field_value3 + '\'' +
                '}';
    }
}

==> applet-service-2.0.0-20200115.062433-3-sources.jar: com/bizvane/appletservice/models/bo/UpdateMemberInfo.java <==
package com.bizvane.appletservice.models.bo;

/**
 * @ClassName UpdateMemberInfo
 * @DescriptTion :
 * @Auther: wd
 * @Date :2018/12/28 14:23
 */
public class UpdateMemberInfo {

    /**
     * code : 179011264953
     * card_id : p1Pj9jr90_SQRaVqYI239Ka1erkI
     * background_pic_url : https://mmbiz.qlogo.cn/mmbiz/0?wx_fmt=jpeg
     * record_bonus : 消费30元，获得3积分
     * bonus : 3000
     * add_bonus : 30
     * balance : 3000
     * add_balance : -30
     * record_balance : 购买焦糖玛琪朵一杯，扣除金额30元。
     * custom_field_value : xxxxx
     * custom_field_value2 : xxxxx
     * notify_optional : {"is_notify_bonus":true,"is_notify_balance":true,"is_notify_custom_field1":true}
     */
    private Long sysBrandId;
    private String code;
    private String card_id;
    private String custom_field_value1;
    private String custom_field_value2;
    private String custom_field_value3;

    private Boolean is_notify_bonus = true;
    private Boolean is_notify_custom_field1 = false;
    private Boolean is_notify_custom_field2 = false;
    private Boolean is_notify_custom_field3 = false;

    public Boolean getIs_notify_custom_field1() {
        return is_notify_custom_field1;
    }

    public void setIs_notify_custom_field1(Boolean is_notify_custom_field1) {
        this.is_notify_custom_field1 = is_notify_custom_field1;
    }

    public Boolean getIs_notify_custom_field2() {
        return is_notify_custom_field2;
    }

    public void setIs_notify_custom_field2(Boolean is_notify_custom_field2) {
        this.is_notify_custom_field2 = is_notify_custom_field2;
    }

    public Boolean getIs_notify_custom_field3() {
        return is_notify_custom_field3;
    }

    public void setIs_notify_custom_field3(Boolean is_notify_custom_field3) {
        this.is_notify_custom_field3 = is_notify_custom_field3;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getCard_id() {
        return card_id;
    }

    public void setCard_id(String card_id) {
        this.card_id = card_id;
    }

    public String getCustom_field_value1() {
        return custom_field_value1;
    }

    public void setCustom_field_value1(String custom_field_value1) {
        this.custom_field_value1 = custom_field_value1;
    }

    public String getCustom_field_value2() {
        return custom_field_value2;
    }

    public void setCustom_field_value2(String custom_field_value2) {
        this.custom_field_value2 = custom_field_value2;
    }

    public String getCustom_field_value3() {
        return custom_field_value3;
    }

    public void setCustom_field_value3(String custom_field_value3) {
        this.custom_field_value3 = custom_field_value3;
    }

    public Boolean getIs_notify_bonus() {
        return is_notify_bonus;
    }
    public void setIs_notify_bonus(Boolean is_notify_bonus) {
        this.is_notify_bonus = is_notify_bonus;
    }

    @Override
    public String toString() {
        return "UpdateMemberInfo{" +
                "sysBrandId=" + sysBrandId +
                ", code='" + code + '\'' +
                ", card_id='" + card_id + '\'' +
                ", custom_field_value1='" + custom_field_value1 + '\'' +
                ", custom_field_value2='" + custom_field_value2 + '\'' +
                ", custom_field_value3='" + custom_field_value3 + '\'' +
                '}';
    }
}
